# ME-GPT


**Create a clone of you - give it information about yourself and let it speak for you.**

# TODO - add a gif here
[Demo]

## Project philosophy
- **Open source** - the project is open source and free to use. We are building the open platform for devs to tinker with and build their personal code-generation toolbox.
- **Clone yourself** - the project is about creating a clone of yourself. You can use it to automate your work, or to create a digital version of yourself that can speak for you.

## Setup
# TODO - [ ] Add setup instructions



**Run**:
# TODO - [ ] Add run instructions

**Results**
# TODO - [ ] Add results


## Features
You can specify the "identity" of the AI agent by editing the files in the `identity` folder.

Editing the identity, and evolving the `memory` of the AI agent will change the way it responds to you.

## Contributing
We are building the open platform for devs to tinker with and build their personal code-generation toolbox.

If you want to contribute, please check out the [roadmap](https://github.com/djm93dev/me-gpt/blob/main/ROADMAP.md), in the GitHub repo. You are welcome to read the [contributing document](.github/CONTRIBUTING.md) for more information.

We are currently looking for more maintainers and community organizers to help us build the community around this project. If you are interested, email - daniel@danielmcdonald.dev if you are interested in an official role.